@@ -109,7 +109,7 @@ def basic_metadata_tweets_extracted (data_tweets, node_list):
         
     data_tweets = data_tweets.rename(columns = {"created_at": "created_at_tw"})
     df_basic_metadata_tweets_extracted = pd.concat([data_tweets.drop(['user'], axis=1), data_tweets['user'].apply(pd.Series)],
-                            axis=1).drop_duplicates().reset_index(drop=True)[["screen_name","followees","followers","statuses_count","url"]]
+                            axis=1).drop_duplicates().reset_index(drop=True)[["screen_name","followees","followers","statuses_count","url","verified"]]
     df_basic_metadata_tweets_extracted["url"] = "http://www.twitter.com/"+df_basic_metadata_tweets_extracted["screen_name"]
 
     extract_profiles =[]
@@ -379,7 +379,10 @@ def graph_features(DiG,df):
     output = merge_dataframes(output, df_nodes_self_loop_iteration)
     return output
     
-def graph_json_values(df_graph, df_basic_data, node_list_df):
+def graph_json_values(df_graph, df_basic_data, node_list_df, from_verified):
+
+    if (from_verified == False):            
+        df_basic_data = df_basic_data[df_basic_data["verified"] != True].reset_index()
 
     #Removing incorrect profile mentions
     tweets_profiles =  list(df_basic_data["screen_name"])
@@ -391,7 +394,7 @@ def graph_json_values(df_graph, df_basic_data, node_list_df):
             delete_profiles.append(item)
 
     df_graph = df_graph[~df_graph["screen_name"].isin(delete_profiles)]
-    df_graph = df_graph[~df_graph["screen_name_mention"].isin(delete_profiles)] 
+    df_graph = df_graph[~df_graph["screen_name_mention"].isin(delete_profiles)]    
     
     data = {}
     data['nodes'] = []
@@ -970,6 +973,7 @@ def advanced_features(data):
     data["max_tw_day"] = 0
     data["index_max_day_tw"]=0
     data["possible_duplicates"] = 0
+    data["fake_type"] = "Normal"
 
     data["num_userTw"]= data["num_ownTw"] + data["RT"]
     data["tw_RT_rate"] = ((((data["num_ownTw"]))) / (data["num_userTw"])).replace([np.inf, -np.inf], np.nan).fillna(0)
@@ -1009,6 +1013,26 @@ def advanced_features(data):
             data["max_ret_tw"].iloc[i] = 0
         else:
             data["max_ret_tw"].iloc[i] = max((data["retweet_tweets_list"].iloc[i]))
+
+        #Differentes types of fake
+        data["default_profile_image"] + data["biography_profile"]+ data["screen_name_bot"]
+        if ((data["default_profile_image"].iloc[i] == 0) & (data["biography_profile"].iloc[i] == 0) & (data["screen_name_bot"].iloc[i] == 0)):
+            data["fake_type"].iloc[i] ="None"
+        if ((data["default_profile_image"].iloc[i] == 1) & (data["biography_profile"].iloc[i] == 0) & (data["screen_name_bot"].iloc[i] == 0)):
+            data["fake_type"].iloc[i] ="Default image"
+        if ((data["default_profile_image"].iloc[i] == 0) & (data["biography_profile"].iloc[i] == 1) & (data["screen_name_bot"].iloc[i] == 0)):
+            data["fake_type"].iloc[i] ="No biography"
+        if ((data["default_profile_image"].iloc[i] == 0) & (data["biography_profile"].iloc[i] == 0) & (data["screen_name_bot"].iloc[i] == 1)):
+            data["fake_type"].iloc[i] ="Last 4 numbers screen_name"
+        if ((data["default_profile_image"].iloc[i] == 1) & (data["biography_profile"].iloc[i] == 1) & (data["screen_name_bot"].iloc[i] == 0)):
+            data["fake_type"].iloc[i] ="Default image + No biography"
+        if ((data["default_profile_image"].iloc[i] == 1) & (data["biography_profile"].iloc[i] == 0) & (data["screen_name_bot"].iloc[i] == 1)):
+            data["fake_type"].iloc[i] ="Default image + Last 4 numbers screen_name"
+        if ((data["default_profile_image"].iloc[i] == 0) & (data["biography_profile"].iloc[i] == 1) & (data["screen_name_bot"].iloc[i] == 1)):
+            data["fake_type"].iloc[i] ="No biography + Last 4 numbers screen_name"
+        if ((data["default_profile_image"].iloc[i] == 1) & (data["biography_profile"].iloc[i] == 1) & (data["screen_name_bot"].iloc[i] == 1)):
+            data["fake_type"].iloc[i] ="All signs of fake account"
+
           
         data["max_tw_day"].iloc[i] =max((data["tw_per_day_list"].iloc[i]))
         data["days_with_tw"].iloc[i] = len(data["tw_per_day_list"].iloc[i])
